---
icon: "material/wrench"
hide:
- toc
---

# Getting started

## Installation

=== "PyPI"

```console
pip install coomsuite
```

=== "Development mode"

```console
git clone https://github.com/potassco/coom-suite.git
cd coomsuite
pip install -e .[all]
```

!!! warning
    Use only for development purposes
